﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            LeCroy WaveAce 202: (1 year) VER DOS /9500+3Hd
DATE:                  2017-04-07 14:16:56
AUTHOR:                LeCroy Corporation
REVISION:              $Revision: 2624 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       174
CONFIGURATION:         Datron 9500 (C5)
CONFIGURATION:         Datron 9510 on channel 1
CONFIGURATION:         Datron 9510 on channel 2
CONFIGURATION:         Datron 9510 on channel 5
=============================================================================
#
#  Procedure Author:
#      FL, DAC, CAD
#
#  Source:
#      Lecroy WaveAce Performance Verification, Rev F
#
#  Compatibility:
#      MET/CAL 7.3 or later
#
#  Additional Equipment Required:
#      Type A male to type B male USB cable.
#
#  Due to OEM's policy of continuously updating products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, we cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  ASK-   R     N              P                   Z        F        V
  1.002  ASK+           K

# Dummy statements to force procedure header to include configuration
# required at run time.
  1.003  IF           0
  1.004  M9500                       CH1
  1.005  9500         60MH                         2Vpp           LS    S  L
  1.006  M9500                       CH2
  1.007  9500         60MH                         2Vpp           LS    S  L
  1.008  M9500                       CH5
  1.009  9500         60MH                         2Vpp           LS    S  L
  1.010  ENDIF

  1.011  IF           NOT(VERSIONCHECK("7.3"))
  1.012  DISP         This procedure requires Met/VERsion 7.3 or later.
  1.013  END
  1.014  ENDIF

  1.015  MATH         @Debug = 0

  1.016  HEAD         PRELIMINARY INSTRUCTIONS
  1.017  CALL         Sub Install LeCroy EasyScope
  1.018  CALL         Sub Display Copyright
  1.019  CALL         Sub High Voltage Safety Warning
  1.020  CALL         Sub Select Verification Method (No NTHROW)

  1.021  DISP         The calibration verification must be performed on
  1.021  DISP         an oscilloscope that has been warmed for at least
  1.021  DISP         15 minutes.  Turn ON and wait now if needed.

  1.022  DISP         Connect the PC to the UUT using Type A male to
  1.022  DISP         Type B male USB cable.

  1.023  MATH         @DataPath = "\"" & DFILE() & "\""

  1.024  HEAD         UUT IDENTIFICATION
  1.025  DOS          -x WaveAce.exe [V @DataPath] *RST

  1.026  MATH         @UUT_Manufacturer = "LECROY"
  1.027  MATH         @UUT_Model        = "WaveAce202"

  1.028  DO
  1.029  DOS          WaveAce.exe [V @DataPath] *IDN?
  1.030  MATH         HaveId = NOT(EMPTY(MEM2)) && FINDI(MEM2, "LeCroy", 0)

  1.031  IF           NOT(HaveId)
  1.032  OPBR         -z An error occurred while Identifying the
  1.032  OPBR         [V @UUT_Model].
  1.032  OPBR
  1.032  OPBR         Would you like to try again?

  1.033  IF           NOT(MEM1)
  1.034  HEAD         Procedure terminated!
  1.035  END
  1.036  ENDIF

  1.037  ENDIF

  1.038  UNTIL        HaveId

# Strip "*IDN " from the UUT's *IDN? response.  Example response:
# "*IDN LECROY,WaveAce<model number>,<serial number>,<firmware revision>"
  1.039  MATH         MEM2 = FLD(MEM2, 2, " ")
  1.040  CALL         Sub IEEE-488.2 Identification Query Parse Response
  1.041  CALL         Sub IEEE-488.2 Identification Query Check Response

  1.042  IF           @Abort
  1.043  END
  1.044  ENDIF

  1.045  IF           NOT(ZCMPI(@FirmwareRev, "1.01.01.13"))
  1.046  DISP         This DOS-based procedure only supports UUTs with
  1.046  DISP         firmware version 1.01.01.13.
  1.046  DISP
  1.046  DISP         All other firmware verions must use the VISA version of
  1.046  DISP         this same procedure.
  1.047  ENDIF

# Set: Number of channels; Bandwidth.
  1.048  MATH         @NumChan = 2; @Bandwidth = 60E+6

  1.049  CALL         Sub LeCroy WaveAce Self Calibration

  1.050  HEAD         INSTRUMENT CONNECTIONS
  1.051  DISP         Make the following connections:
  1.051  DISP
  1.051  DISP         [32]       9500          to     UUT
  1.051  DISP         [32]  CH 1 ACTIVE HEAD -------> CH1
  1.051  DISP         [32]  CH 2 ACTIVE HEAD -------> CH2
  1.051  DISP         [32]  CH 5 ACTIVE HEAD -------> EXT TRIG

  1.052  MATH         @Chan = 1
  1.053  M9500                       CH1
  1.054  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500

  1.055  MATH         @Chan = 2
  1.056  M9500                       CH2
  1.057  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500

  1.058  M9500                       CH5
  1.059  CALL         Sub LeCroy WaveAce (1 yr) Ext Input Imped VER DOS /9500

  1.060  MATH         @Chan = 1
  1.061  M9500                       CH1
  1.062  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500

  1.063  MATH         @Chan = 2
  1.064  M9500                       CH2
  1.065  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500

  1.066  MATH         @Chan = 1
  1.067  M9500                       CH1
  1.068  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500

  1.069  MATH         @Chan = 2
  1.070  M9500                       CH2
  1.071  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500

  1.072  MATH         @Chan = 1
  1.073  M9500                       CH1
  1.074  CALL         Sub LeCroy WaveAce (1 yr) Horizontal Acc VER DOS /9500

  1.075  MATH         @Chan = 1
  1.076  M9500                       CH1
  1.077  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500

  1.078  MATH         @Chan = 2
  1.079  M9500                       CH2
  1.080  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500

  1.081  MATH         @Chan = 1
  1.082  M9500                       CH1                                   1T5
  1.083  CALL         Sub LeCroy WaveAce (1 yr) Ext Trig Sens VER DOS /9500

  1.084  RSLT         =
  1.085  HEAD         {V E R I F I C A T I O N   C O M P L E T E}
  1.086  END
